@@ -62,6 +62,9 @@ pref("browser.cache.memory.enable",         true);
 pref("browser.cache.disk_cache_ssl",        false);
 // 0 = once-per-session, 1 = each-time, 2 = never, 3 = when-appropriate/automatically
 pref("browser.cache.check_doc_frequency",   3);
+// Fastback caching - if this pref is negative, then we calculate the number
+// of content viewers to cache based on the amount of available memory.
+pref("browser.sessionhistory.max_total_viewers", -1);
 
 pref("browser.display.use_document_fonts",  1);  // 0 = never, 1 = quick, 2 = always
 pref("browser.display.use_document_colors", true);
@@ -95,12 +98,15 @@ pref("browser.helperApps.neverAsk.openFile", "");
 pref("browser.chrome.toolbar_tips",         true);
 // 0 = Pictures Only, 1 = Text Only, 2 = Pictures and Text
 pref("browser.chrome.toolbar_style",        2);
+// max image size for which it is placed in the tab icon for tabbrowser.
+// if 0, no images are used for tab icons for image documents.
+pref("browser.chrome.image_icons.max_size", 1024);
 
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 104 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 110 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -108,7 +114,7 @@ pref("accessibility.warn_on_browsewithcaret", true);
 // unless accessibility.tabfocus is set by the user.
 pref("accessibility.tabfocus", 7);
 pref("accessibility.tabfocus_applies_to_xul", false);
-//@line 115 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 121 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -336,8 +342,8 @@ pref("capability.policy.mailnews.XMLHttpRequest.onerror", "noAccess");
 pref("capability.policy.mailnews.XMLHttpRequest.onreadystatechange", "noAccess");
 pref("capability.policy.mailnews.XMLSerializer.serializeToString", "noAccess");
 pref("capability.policy.mailnews.XMLSerializer.serializeToStream", "noAccess");
-pref("capability.policy.mailnews.DOMParser,parseFromString", "noAccess");
-pref("capability.policy.mailnews.DOMParser,parseFromStream", "noAccess");
+pref("capability.policy.mailnews.DOMParser.parseFromString", "noAccess");
+pref("capability.policy.mailnews.DOMParser.parseFromStream", "noAccess");
 pref("capability.policy.mailnews.SOAPCall.transportURI", "noAccess");
 pref("capability.policy.mailnews.SOAPCall.verifySourceHeader", "noAccess");
 pref("capability.policy.mailnews.SOAPCall.invoke", "noAccess");
@@ -430,7 +436,6 @@ pref("javascript.allow.mailnews",           false);
 pref("javascript.options.strict",           false);
 
 // advanced prefs
-pref("advanced.always_load_images",         true);
 pref("security.enable_java",                true);
 pref("advanced.mailftp",                    false);
 pref("image.animation_mode",                "normal");
@@ -455,7 +460,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-pref("network.protocol-handler.external.help", false);
+//@line 469 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -561,17 +566,44 @@ pref("network.IDN_show_punycode", false);
 // are referred to ONLY when "network.IDN_show_punycode" is false. In other
 // words, all IDNs will be shown in punycode if "network.IDN_show_punycode"
 // is true.
+
+// ccTLDs
+pref("network.IDN.whitelist.ac", true);
 pref("network.IDN.whitelist.at", true);
+pref("network.IDN.whitelist.br", true);
 pref("network.IDN.whitelist.ch", true);
+pref("network.IDN.whitelist.cl", true);
 pref("network.IDN.whitelist.cn", true);
 pref("network.IDN.whitelist.de", true);
 pref("network.IDN.whitelist.dk", true);
+pref("network.IDN.whitelist.fi", true);
+pref("network.IDN.whitelist.gr", true);
+pref("network.IDN.whitelist.hu", true);
+pref("network.IDN.whitelist.io", true);
 pref("network.IDN.whitelist.jp", true);
 pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
+pref("network.IDN.whitelist.lt", true);
 pref("network.IDN.whitelist.no", true);
 pref("network.IDN.whitelist.se", true);
+pref("network.IDN.whitelist.sh", true);
+pref("network.IDN.whitelist.th", true);
+pref("network.IDN.whitelist.tm", true);
 pref("network.IDN.whitelist.tw", true);
+pref("network.IDN.whitelist.vn", true);
+
+// non-ccTLDs
+pref("network.IDN.whitelist.info", true);
+pref("network.IDN.whitelist.museum", true);
+
+// If a domain includes any of the following characters, it may be a spoof 
+// attempt and so we always display the domain name as punycode. This would 
+// override the settings "network.IDN_show_punycode" and 
+// "netword.IDN.whitelist.*".
+// The list currently contains the characters:
+// U+2044 FRACTION SLASH
+// U+2215 DIVISION SLASH
+pref("network.IDN.blacklist_chars", "⁄∕");
 
 // This preference specifies a list of domains for which DNS lookups will be
 // IPv4 only. Works around broken DNS servers which can't handle IPv6 lookups
@@ -587,7 +619,7 @@ pref("network.standard-url.escape-utf8", true);
 
 // This preference controls whether or not URLs are always encoded and sent as
 // UTF-8.
-pref("network.standard-url.encode-utf8", true);
+pref("network.standard-url.encode-utf8", false);
 
 // Idle timeout for ftp control connections - 5 minute default
 pref("network.ftp.idleConnectionTimeout", 300);
@@ -624,6 +656,8 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
+//@line 670 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
 // Window's domain logon.  The trusted-uris pref follows the format of the
@@ -686,6 +720,7 @@ pref("intl.accept_languages",               "chrome://navigator/locale/navigator
 pref("intl.accept_charsets",                "iso-8859-1,*,utf-8");
 pref("intl.collationOption",                "chrome://navigator-platform/locale/navigator.properties");
 pref("intl.menuitems.alwaysappendaccesskeys","chrome://navigator/locale/navigator.properties");
+pref("intl.menuitems.insertseparatorbeforeaccesskeys","chrome://navigator/locale/navigator.properties");
 pref("intl.charsetmenu.browser.static",     "chrome://navigator/locale/navigator.properties");
 pref("intl.charsetmenu.browser.more1",      "chrome://navigator/locale/navigator.properties");
 pref("intl.charsetmenu.browser.more2",      "chrome://navigator/locale/navigator.properties");
@@ -743,16 +778,20 @@ pref("mousewheel.withnokey.sysnumlines",true);
 pref("mousewheel.withcontrolkey.action",0);
 pref("mousewheel.withcontrolkey.numlines",1);
 pref("mousewheel.withcontrolkey.sysnumlines",true);
+// mousewheel.withshiftkey, see the Mac note below.
 pref("mousewheel.withshiftkey.action",0);
 pref("mousewheel.withshiftkey.numlines",1);
 pref("mousewheel.withshiftkey.sysnumlines",true);
 pref("mousewheel.withaltkey.action",2);
 pref("mousewheel.withaltkey.numlines",1);
 pref("mousewheel.withaltkey.sysnumlines",false);
+pref("mousewheel.withmetakey.action",0);
+pref("mousewheel.withmetakey.numlines",1);
+pref("mousewheel.withmetakey.sysnumlines",true);
 
 // on platforms where scroll messages differ between horizontal scroll
 // and back/forward button events we can activate them by default
-//@line 783 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 839 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 // disable horizontal scrolling to be able to use back/forward buttons
 pref("mousewheel.horizscroll.withnokey.action",2);
 pref("mousewheel.horizscroll.withnokey.numlines",-1);
@@ -766,7 +805,10 @@ pref("mousewheel.horizscroll.withshiftkey.sysnumlines",false);
 pref("mousewheel.horizscroll.withaltkey.action",2);
 pref("mousewheel.horizscroll.withaltkey.numlines",-1);
 pref("mousewheel.horizscroll.withaltkey.sysnumlines",false);
-//@line 797 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+pref("mousewheel.horizscroll.withmetakey.action",2);
+pref("mousewheel.horizscroll.withmetakey.numlines",-1);
+pref("mousewheel.horizscroll.withmetakey.sysnumlines",false);
+//@line 856 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
 pref("profile.confirm_automigration",true);
 // profile.migration_behavior determines how the profiles root is set
@@ -899,15 +941,15 @@ pref("dom.max_script_run_time", 5);
 
 pref("svg.enabled", true);
 
-//@line 1260 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 1319 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1450 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 1506 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1635 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 1691 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1716 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 1772 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1719 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 1775 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -983,7 +1025,7 @@ pref("font.allow_double_byte_special_chars", true);
 
 // ar
 
-//@line 1795 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 1851 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.name.serif.el", "serif");
 pref("font.name.sans-serif.el", "sans-serif");
@@ -1042,7 +1084,7 @@ pref("font.name.sans-serif.zh-HK", "sans-serif");
 pref("font.name.monospace.zh-HK", "monospace");
 
 // zh-TW
-//@line 1914 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 1970 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.default.ar", "sans-serif");
 pref("font.size.variable.ar", 16);
@@ -1260,11 +1302,11 @@ pref("print.postscript.nativefont.zh-CN",          "");
 pref("print.postscript.nativefont.zh-TW",          "");
 pref("print.postscript.nativefont.zh-HK",          "");
 
-//@line 2134 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2190 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2202 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2258 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2228 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2284 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2248 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2304 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
