@@ -1,4 +1,4 @@
-//@line 40 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mail3PaneWindowCommands.js"
+//@line 40 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mail3PaneWindowCommands.js"
 
 var promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].getService(Components.interfaces.nsIPromptService);
 var gMessengerBundle = document.getElementById("bundle_messenger");
@@ -445,20 +445,14 @@ var DefaultController =
 			case "cmd_delete":
          // if the user deletes a message before its mark as read timer goes off, we should mark it as read
          // this ensures that we clear the biff indicator from the system tray when the user deletes the new message
-        if (gMarkViewedMessageAsReadTimer) 
-        {
+        if (gMarkViewedMessageAsReadTimer)
           MarkCurrentMessageAsRead();
-          ClearPendingReadTimer();
-        }
         SetNextMessageAfterDelete();
         gDBView.doCommand(nsMsgViewCommandType.deleteMsg);
 				break;
 			case "cmd_shiftDelete":
         if (gMarkViewedMessageAsReadTimer)
-        {
           MarkCurrentMessageAsRead();
-          ClearPendingReadTimer();
-        }
         SetNextMessageAfterDelete();
         gDBView.doCommand(nsMsgViewCommandType.deleteNoTrash);
 				break;
