@@ -1,4 +1,4 @@
-//@line 37 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 37 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
 
 ///////////////////////////////////////////////////////////////////////////////
 // Globals
@@ -34,11 +34,13 @@ const OP_NEEDS_UNINSTALL              = "needs-uninstall";
 const OP_NEEDS_ENABLE                 = "needs-enable";
 const OP_NEEDS_DISABLE                = "needs-disable";
 
-const URI_EXTENSION_UPDATE_DIALOG     = "chrome://mozapps/content/extensions/update.xul";
-
 ///////////////////////////////////////////////////////////////////////////////
 // Utility Functions 
 
+function LOG(msg) {
+  dump("*** " + msg + "\n");
+}
+
 function getIDFromResourceURI(aURI) 
 {
   if (aURI.substring(0, PREFIX_ITEM_URI.length) == PREFIX_ITEM_URI) 
@@ -48,7 +50,7 @@ function getIDFromResourceURI(aURI)
 
 function openURL(aURL)
 {
-//@line 88 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 90 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
   var uri = Components.classes["@mozilla.org/network/io-service;1"]
                       .getService(Components.interfaces.nsIIOService)
                       .newURI(aURL, null, null);
@@ -56,7 +58,7 @@ function openURL(aURL)
   var protocolSvc = Components.classes["@mozilla.org/uriloader/external-protocol-service;1"]
                               .getService(Components.interfaces.nsIExternalProtocolService);
   protocolSvc.loadUrl(uri);
-//@line 99 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 101 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
 }
 
 function flushDataSource()
@@ -89,12 +91,11 @@ function setRestartMessage(aItem)
 
 ///////////////////////////////////////////////////////////////////////////////
 // Event Handlers
-function onExtensionSelect(aEvent)
+function onExtensionUpdateNow(aEvent)
 {
-  if (aEvent.target.selectedItem)
-    aEvent.target.setAttribute("last-selected", aEvent.target.selectedItem.id);
-  else
-    aEvent.target.removeAttribute("last-selected");
+  var item = gExtensionManager.getItemForID(getIDFromResourceURI(
+    aEvent.target.id));
+  gExtensionManager.addDownloads([item], 1, true);
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -120,20 +121,14 @@ function Startup()
   // Extension Command Updating is handled by a command controller.
   gExtensionsView.controllers.appendController(gExtensionsViewController);
 
-  // This persists the last-selected extension
-  gExtensionsView.addEventListener("richview-select", onExtensionSelect, false);
+  gExtensionsView.addEventListener("extension-updatenow", onExtensionUpdateNow, false);
 
-  // Finally, update the UI. 
-  gExtensionsView.database.AddDataSource(gExtensionManager.datasource);
-  gExtensionsView.setAttribute("ref", RDFURI_ITEM_ROOT);
-  gExtensionsView.focus();
-  
   var pref = Components.classes["@mozilla.org/preferences-service;1"]
                        .getService(Components.interfaces.nsIPrefBranch);
   var defaultPref = pref.QueryInterface(Components.interfaces.nsIPrefService)
                         .getDefaultBranch(null);
   if (!isExtensions) {
-    gExtensionsView.addEventListener("richview-select", onThemeSelect, false);
+    gExtensionsView.addEventListener("select", onThemeSelect, false);
 
     try {
         gCurrentTheme = pref.getCharPref(PREF_GENERAL_SKINS_SELECTEDSKIN);
@@ -147,11 +142,12 @@ function Startup()
     var optionsButton = document.getElementById("optionsButton");
     optionsButton.hidden = true;
   }
-  
-  // Initialize the richlistbox.  This will select the last selected extension
-  // or default to the first listed one.
-  gExtensionsView.init();
 
+  // Finally, update the UI. 
+  gExtensionsView.database.AddDataSource(gExtensionManager.datasource);
+  gExtensionsView.setAttribute("ref", RDFURI_ITEM_ROOT);
+  gExtensionsView.focus();
+  
   var extensionsStrings = document.getElementById("extensionsStrings");
   document.title = extensionsStrings.getString(gWindowState + "Title");
   
@@ -167,6 +163,7 @@ function Startup()
   var getMore = document.getElementById("getMore");
   getMore.setAttribute("value", getMore.getAttribute(isExtensions ? "valueextensions" : "valuethemes"));
   getMore.setAttribute("tooltiptext", getMore.getAttribute(isExtensions ? "tooltiptextextensions" : "tooltiptextthemes"));
+  getMore.setAttribute('href', gGetMoreURL);
   
   if (!isExtensions) {
     var themePreviewArea = document.getElementById("themePreviewArea");
@@ -188,21 +185,24 @@ function Startup()
                      .getService(Components.interfaces.nsIObserverService);
   os.addObserver(gDownloadManager, "xpinstall-download-started", false);
 
-  gObserverIndex = gExtensionManager.addDownloadListener(gDownloadManager);
+  gObserverIndex = gExtensionManager.addUpdateListener(gDownloadManager);
   
   if ("arguments" in window) {
     try {
       var params = window.arguments[0].QueryInterface(Components.interfaces.nsIDialogParamBlock);
       gDownloadManager.addDownloads(params);
     }
-    catch (e) { }
+    catch (e) {
+      if (window.arguments[0] == "updatecheck")
+        performUpdate();
+    }
   }
   
   // Set the tooltips
   if (!isExtensions) {
-//@line 243 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 243 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
     document.getElementById("installButton").setAttribute("tooltiptext", extensionsStrings.getString("cmdInstallTooltipTheme"));
-//@line 245 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 245 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
     document.getElementById("uninstallButton").setAttribute("tooltiptext", extensionsStrings.getString("cmdUninstallTooltipTheme"));
     document.getElementById("updateButton").setAttribute("tooltiptext", extensionsStrings.getString("cmdUpdateTooltipTheme"));
   }
@@ -211,13 +211,13 @@ function Startup()
 function Shutdown() 
 {
   if (gWindowState != "extensions")
-    gExtensionsView.removeEventListener("richview-select", onThemeSelect, false);
-  
-  gExtensionsView.removeEventListener("richview-select", onExtensionSelect, false);
+    gExtensionsView.removeEventListener("select", onThemeSelect, false);
+
+  gExtensionsView.removeEventListener("extension-updatenow", onExtensionUpdateNow, false);
 
   gExtensionsView.database.RemoveDataSource(gExtensionManager.datasource);
 
-  gExtensionManager.removeDownloadListenerAt(gObserverIndex);
+  gExtensionManager.removeUpdateListenerAt(gObserverIndex);
 
   var os = Components.classes["@mozilla.org/observer-service;1"]
                      .getService(Components.interfaces.nsIObserverService);
@@ -280,31 +280,33 @@ XPInstallDownloadManager.prototype = {
       }
       
       var type = isExtensions ? nsIUpdateItem.TYPE_EXTENSION : nsIUpdateItem.TYPE_THEME;
-      // gExtensionManager.addDownload(displayName, url, iconURL, type);
       var item = Components.classes["@mozilla.org/updates/item;1"]
                            .createInstance(Components.interfaces.nsIUpdateItem);
-      item.init(url, " ", "app-profile", "", "", displayName, url, iconURL, "", type);
+      item.init(url, " ", "app-profile", "", "", displayName, url, "", iconURL, "", type);
       items.push(item);
 
       // Advance the enumerator
       var certName = aParams.GetString(i++);
     }
     
-    gExtensionManager.addDownloads(items, items.length);
+    gExtensionManager.addDownloads(items, items.length, false);
     gExtensionsView.scrollBoxObject.ensureElementIsVisible(gExtensionsView.lastChild);
   },
-
-  removeDownload: function (aEvent)
+  
+  getElementForAddon: function(aAddon) 
   {
-  
+    var element = document.getElementById(PREFIX_ITEM_URI + aAddon.id);
+    if (aAddon.id == aAddon.xpiURL)
+      element = document.getElementById(aAddon.xpiURL);
+    return element;
   },
-  
+
   /////////////////////////////////////////////////////////////////////////////  
-  // nsIExtensionDownloadListener
-  onStateChange: function (aURL, aState, aValue)
+  // nsIAddonUpdateListener
+  onStateChange: function (aAddon, aState, aValue)
   {
     const nsIXPIProgressDialog = Components.interfaces.nsIXPIProgressDialog;
-    var element = document.getElementById(aURL);
+    var element = this.getElementForAddon(aAddon);
     if (!element) return;
     switch (aState) {
       case nsIXPIProgressDialog.DOWNLOAD_START:
@@ -327,7 +329,7 @@ XPInstallDownloadManager.prototype = {
                              extensionsStrings.getString("installInstalling"));
         break;
       case nsIXPIProgressDialog.INSTALL_DONE:
-        dump("*** state change = " + aURL + ", state = " + aState + ", value = " + aValue + "\n");
+        dump("*** state change = " + aAddon.xpiURL + ", state = " + aState + ", value = " + aValue + "\n");
         element.setAttribute("state", "done");
         extensionsStrings = document.getElementById("extensionsStrings");
         element.setAttribute("description",
@@ -348,7 +350,7 @@ XPInstallDownloadManager.prototype = {
 
           var brandStrings = sbs.createBundle("chrome://branding/locale/brand.properties");
           var brandShortName = brandStrings.GetStringFromName("brandShortName");
-          var params = [brandShortName, aURL, msg];
+          var params = [brandShortName, aAddon.xpiURL, msg];
           var message = extensionStrings.formatStringFromName("errorInstallMsg", params, params.length);
 
           var ps = Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
@@ -356,10 +358,11 @@ XPInstallDownloadManager.prototype = {
           ps.alert(window, title, message);
           element.setAttribute("status", msg);
         }
-        // Remove the dummy, since we installed successfully
+        // Remove the dummy, since we installed successfully (only if we're a URL, 
+        // not a download operation on an existing item.
         var type = gWindowState == "extensions" ? nsIUpdateItem.TYPE_EXTENSION
                                                 : nsIUpdateItem.TYPE_THEME;
-        gExtensionManager.removeDownload(aURL);
+        gExtensionManager.removeDownload(aAddon.xpiURL);
         break;
       case nsIXPIProgressDialog.DIALOG_CLOSE:
         break;
@@ -367,13 +370,13 @@ XPInstallDownloadManager.prototype = {
   },
   
   _urls: { },
-  onProgress: function (aURL, aValue, aMaxValue)
+  onProgress: function (aAddon, aValue, aMaxValue)
   {
-    var element = document.getElementById(aURL);
+    var element = this.getElementForAddon(aAddon);
     if (!element) return;
     var percent = Math.round((aValue / aMaxValue) * 100);
-    if (percent > 1 && !(aURL in this._urls)) {
-      this._urls[aURL] = true;
+    if (percent > 1 && !(aAddon.xpiURL in this._urls)) {
+      this._urls[aAddon.xpiURL] = true;
       element.setAttribute("state", "downloading");
     }
     element.setAttribute("progress", percent);
@@ -428,13 +431,125 @@ XPInstallDownloadManager.prototype = {
   // nsISupports
   QueryInterface: function (aIID) 
   {
-    if (!aIID.equals(Components.interfaces.nsIExtensionDownloadListener) &&
+    if (!aIID.equals(Components.interfaces.nsIAddonUpdateListener) &&
         !aIID.equals(Components.interfaces.nsISupports))
       throw Components.results.NS_ERROR_NO_INTERFACE;
     return this;
   }
 };
 
+///////////////////////////////////////////////////////////////////////////////
+//
+// Update Listener
+//
+function UpdateCheckListener() {
+  this._addons = [];
+}
+UpdateCheckListener.prototype = {
+  /**
+   * A list of addons we've found updates to in this update check transaction.
+   */
+  _addons: [],
+  
+  /**
+   * See nsIExtensionManager.idl
+   */
+  onUpdateStarted: function() {
+    gExtensionsView.setAttribute("update-check", "true");
+    var command = document.getElementById("cmd_update");
+    command.setAttribute("disabled", "true");
+    command = document.getElementById("cmd_update_all");
+    command.setAttribute("disabled", "true");
+  },
+  
+  /**
+   * See nsIExtensionManager.idl
+   */
+  onUpdateEnded: function() {
+    gExtensionsView.removeAttribute("update-check");
+    var command = document.getElementById("cmd_update");
+    gExtensionsViewController.updateCommand(command);
+    command = document.getElementById("cmd_update_all");
+    command.removeAttribute("disabled");
+    
+    // Show message to user listing extensions for which updates are available
+    // and prompt to install now.
+    if (this._addons.length == 1) {
+      var element = document.getElementById(PREFIX_ITEM_URI + this._addons[0].id);
+      gExtensionsView.scrollBoxObject.scrollToElement(element);
+    }
+    else if (this._addons.length > 1) {
+      var strings = document.getElementById("extensionsStrings");
+      var brandName = document.getElementById("brandStrings").getString("brandShortName");
+      var params = {
+        message1: strings.getFormattedString("updatesAvailableMessage1",
+                                             [brandName]),
+        message2: strings.getString("updatesAvailableMessage2"),
+        title: strings.getString("updatesAvailableTitle"),
+        buttons: {
+          accept: { label: strings.getString("updatesAvailableAccept"),
+                    focused: true },
+          cancel: { label: strings.getString("updatesAvailableCancel") }
+        }
+      }
+      var names = [];
+      for (var i = 0; i < this._addons.length; ++i) {
+        var addon = this._addons[i];
+        var existingItem = gExtensionManager.getItemForID(addon.id);
+        var name = strings.getFormattedString("itemFormat", 
+                                              [this._addons[i].name, 
+                                               existingItem.version,
+                                               this._addons[i].version]);
+        names.push(name);
+      }
+      openDialog("chrome://mozapps/content/extensions/list.xul", "", 
+                 "titlebar,modal", names, params);
+      if (params.result == "accept") 
+        gExtensionManager.addDownloads(this._addons, this._addons.length, true);
+    }
+  },
+  
+  /**
+   * See nsIExtensionManager.idl
+   */
+  onAddonUpdateStarted: function(addon) {
+    var element = document.getElementById(PREFIX_ITEM_URI + addon.id);
+    element.setAttribute("loading", "true");
+  },
+  
+  /**
+   * See nsIExtensionManager.idl
+   */
+  onAddonUpdateEnded: function(addon, status) {
+    var element = document.getElementById(PREFIX_ITEM_URI + addon.id);
+    element.removeAttribute("loading");
+    const nsIAUCL = Components.interfaces.nsIAddonUpdateCheckListener;
+    var strings = document.getElementById("extensionsStrings");
+    switch (status) {
+    case nsIAUCL.STATUS_UPDATE:
+      this._addons.push(addon);
+      break;
+    case nsIAUCL.STATUS_FAILURE:
+      element.setAttribute("description", strings.getString("updateFailedMsg"));
+      break;
+    case nsIAUCL.STATUS_DISABLED:
+      element.setAttribute("description", strings.getString("updateDisabledMsg")); 
+      break;
+    }
+  },
+  
+  /**
+   * See nsISupports.idl
+   */
+  QueryInterface: function(iid) {
+    if (!iid.equals(Components.interfaces.nsIAddonUpdateCheckListener) &&
+        !iid.equals(Components.interfaces.nsISupports))
+      throw Components.results.NS_ERROR_NO_INTERFACE;
+    return this;
+  }
+};
+
+
 ///////////////////////////////////////////////////////////////////////////////
 //
 // View Event Handlers
@@ -479,11 +594,10 @@ function onThemeSelect(aEvent)
 var gExtensionContextMenus = ["menuitem_options", "menuitem_homepage", "menuitem_about", 
                               "menuseparator_1", "menuitem_uninstall", "menuitem_update",
                               "menuitem_enable", "menuitem_disable", "menuseparator_2", 
-                              "menuitem_moveTop", "menuitem_moveUp", "menuitem_moveDn",
-                              "menuseparator_3", "menuitem_showFolder"];
+                              "menuitem_moveTop", "menuitem_moveUp", "menuitem_moveDn"];
 var gThemeContextMenus = ["menuitem_useTheme", "menuitem_homepage", "menuitem_about", 
                           "menuseparator_1", "menuitem_uninstall", "menuitem_update",
-                          "menuitem_enable", "menuseparator_3", "menuitem_showFolder"];
+                          "menuitem_enable"];
 
 function buildContextMenu(aEvent)
 {
@@ -601,16 +715,10 @@ var gExtensionsDNDObserver =
 
   onDragEnter: function (aEvent, aDragSession)
   {
-    this._ensureServices();
-
-    var count = aDragSession.numDropItems;
-    for (var i = 0; i < count; ++i) {
-      var fileData = this._getDataFromDragSession(aDragSession, i);
-      if (!fileData) {
-        this._canDrop = false;
-        return;
-      }
-    }
+    // XXXrstrong - bug 269568, GTK2 drag and drop is returning invalid data for
+    // dragenter and dragover. To workaround this we always set canDrop to true
+    // and just use the xfer data returned in ondrop which is valid.
+//@line 772 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
     this._canDrop = true;
   },
 
@@ -629,7 +737,7 @@ var gExtensionsDNDObserver =
     for (var i = 0; i < count; ++i) {
       var fileData = this._getDataFromDragSession(aDragSession, i);
       if (!fileData)
-        return;
+        continue;
 
       if (fileData.type == nsIUpdateItem.TYPE_EXTENSION) {
         xpinstallObj[fileData.fileName] = fileData.fileURL;
@@ -673,6 +781,10 @@ function canWriteToLocation(element)
   return installLocation ? installLocation.canAccess : false;
 }
 
+function performUpdate()
+{
+  gExtensionsViewController.commands.cmd_update(null);
+}
 
 var gExtensionsViewController = {
   supportsCommand: function (aCommand)
@@ -723,9 +835,12 @@ var gExtensionsViewController = {
              selectedItem.getAttribute("locked") != "true" &&
              canWriteToLocation(selectedItem);
     case "cmd_update":
-      return !selectedItem && gExtensionsView.children.length > 0 ||
-             (selectedItem &&
-              selectedItem.getAttribute("updateable") != "false");
+      return selectedItem &&
+             selectedItem.getAttribute("updateable") != "false" &&
+             !gExtensionsView.hasAttribute("update-check");
+    case "cmd_update_all":
+      return gExtensionsView.children.length > 0 &&
+             !gExtensionsView.hasAttribute("update-check");
     case "cmd_reallyEnable":
     // controls whether to show Enable or Disable in extensions' context menu
       return selectedItem && 
@@ -751,13 +866,10 @@ var gExtensionsViewController = {
     case "cmd_movedn":
       var children = gExtensionsView.children;
       return selectedItem && (children[children.length-1] != selectedItem);
-    case "cmd_showFolder":
-      return selectedItem && 
-             opType != OP_NEEDS_INSTALL;
-//@line 797 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 920 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
     case "cmd_install":
       return true;   
-//@line 800 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 923 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
     }
     return false;
   },
@@ -771,13 +883,16 @@ var gExtensionsViewController = {
   onCommandUpdate: function ()
   {
     var extensionsCommands = document.getElementById("extensionsCommands");
-    for (var i = 0; i < extensionsCommands.childNodes.length; ++i) {
-      var command = extensionsCommands.childNodes[i];
-      if (this.isCommandEnabled(command.id))
-        command.removeAttribute("disabled");
-      else
-        command.setAttribute("disabled", "true");
-    }
+    for (var i = 0; i < extensionsCommands.childNodes.length; ++i)
+      this.updateCommand(extensionsCommands.childNodes[i]);
+  },
+  
+  updateCommand: function (command) 
+  {
+    if (this.isCommandEnabled(command.id))
+      command.removeAttribute("disabled");
+    else
+      command.setAttribute("disabled", "true");
   },
   
   commands: { 
@@ -853,7 +968,6 @@ var gExtensionsViewController = {
       var movingID = aSelectedItem.id;
       var moveTopID = gExtensionsView.children[0].id;
       gExtensionManager.moveToIndexOf(movingID, moveTopID);
-      gExtensionsView.selectedItem = document.getElementById(movingID);
     },
     
     cmd_moveup: function (aSelectedItem)
@@ -861,7 +975,6 @@ var gExtensionsViewController = {
       var movingID = aSelectedItem.id;
       var moveAboveID = aSelectedItem.previousSibling.id;
       gExtensionManager.moveToIndexOf(movingID, moveAboveID);
-      gExtensionsView.selectedItem = document.getElementById(movingID);
     },
     
     cmd_movedn: function (aSelectedItem)
@@ -869,34 +982,26 @@ var gExtensionsViewController = {
       var movingID = aSelectedItem.id;
       var moveBelowID = aSelectedItem.nextSibling.id;
       gExtensionManager.moveToIndexOf(movingID, moveBelowID);
-      gExtensionsView.selectedItem = document.getElementById(movingID);
     },
     
     cmd_update: function (aSelectedItem)
     { 
-      var id = aSelectedItem ? getIDFromResourceURI(aSelectedItem.id) : null;
-      var itemType = gWindowState == "extensions" ? nsIUpdateItem.TYPE_EXTENSION : nsIUpdateItem.TYPE_THEME;
-      var items = id ? [gExtensionManager.getItemForID(id)] : [];
-      
-      var ary = Components.classes["@mozilla.org/supports-array;1"]
-                          .createInstance(Components.interfaces.nsISupportsArray);
-      var updateTypes = Components.classes["@mozilla.org/supports-PRUint8;1"]
-                                  .createInstance(Components.interfaces.nsISupportsPRUint8);
-      updateTypes.data = itemType;
-      ary.AppendElement(updateTypes);
-      var sourceEvent = Components.classes["@mozilla.org/supports-PRBool;1"]
-                                  .createInstance(Components.interfaces.nsISupportsPRBool);
-      sourceEvent.data = false;
-      ary.AppendElement(sourceEvent);
-      for (var i = 0; i < items.length; ++i)
-        ary.AppendElement(items[i]);
+      var items = [];
+      if (!aSelectedItem)
+        items = gExtensionManager.getItemList(gItemType, { });
+      else {
+        var id = getIDFromResourceURI(aSelectedItem.id);
+        items = [gExtensionManager.getItemForID(id)];
+      }
+      var listener = new UpdateCheckListener();
+      gExtensionManager.update(items, items.length, false, listener);
+    },
 
-      var features = "chrome,centerscreen,dialog,titlebar";
-      // This *must* be modal so as not to break startup! This code is invoked before
-      // the main event loop is initiated (via checkForMismatches).
-      var ww = Components.classes["@mozilla.org/embedcomp/window-watcher;1"]
-                         .getService(Components.interfaces.nsIWindowWatcher);
-      ww.openWindow(window, URI_EXTENSION_UPDATE_DIALOG, "", features, ary);
+    cmd_update_all: function (aSelectedItem)
+    {
+      var items = gExtensionManager.getItemList(gItemType, { });
+      var listener = new UpdateCheckListener();
+      gExtensionManager.update(items, items.length, false, listener);
     },
 
     cmd_uninstall: function (aSelectedItem)
@@ -936,26 +1041,15 @@ var gExtensionsViewController = {
 
     },
 
-    cmd_showFolder: function (aSelectedItem)
-    {
-      var id = getIDFromResourceURI(aSelectedItem.id);
-      var installLocation = gExtensionManager.getInstallLocation(id);
-      var location = installLocation.getItemLocation(id);
-      if (location instanceof Components.interfaces.nsILocalFile)
-        location.reveal();
-    },
-    
     cmd_disable: function (aSelectedItem)
     {
       gExtensionManager.disableItem(getIDFromResourceURI(aSelectedItem.id));
-      gExtensionsView.selectedItem = document.getElementById(aSelectedItem.id);
     },
     
     cmd_enable: function (aSelectedItem)
     {
       gExtensionManager.enableItem(getIDFromResourceURI(aSelectedItem.id));
-      gExtensionsView.selectedItem = document.getElementById(aSelectedItem.id);
-//@line 1002 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 1107 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
     },
 
     cmd_install: function(aSelectedItem)
